@@ -6,11 +6,11 @@ use Exporter 'import';
 our @EXPORT_OK = qw/ db_duplicate_error /;
 
 sub db_duplicate_error {
-    DbError::Duplicate->throw;
+    BoardStreams::Exception::DbError::Duplicate->throw;
 }
 
 
-package DbError;
+package BoardStreams::Exception::DbError;
 
 use Moo;
 with 'Throwable';
@@ -21,10 +21,10 @@ has desc => (
 );
 
 
-package DbError::Duplicate;
+package BoardStreams::Exception::DbError::Duplicate;
 
 use Moo;
-extends 'DbError';
+extends 'BoardStreams::Exception::DbError';
 
 has '+desc' => (
     default => 'Attempted to create row with duplicate key.'
