@@ -12,14 +12,14 @@ our @EXPORT_OK = qw/ get_listener_observable /;
 
 my %listener_observables;
 
-sub get_listener_observable ($c, $channel_name) {
+sub get_listener_observable ($c, $channel_name, $prefix) {
     return $listener_observables{$channel_name} //= rx_observable->new(sub ($subscriber) {
-        my $cb = $c->bs->pubsub->json($channel_name)->listen($channel_name => sub ($pubsub, $payload) {
+        my $cb = $c->$prefix->pubsub->json($channel_name)->listen($channel_name => sub ($pubsub, $payload) {
             $subscriber->next($payload);
         });
 
         return sub {
-            $c->bs->pubsub->unlisten($channel_name => $cb);
+            $c->$prefix->pubsub->unlisten($channel_name => $cb);
             delete $listener_observables{$channel_name};
         };
     })->pipe(
